@@ -32,35 +32,32 @@
 
 /*
  $Log: CORBA_sysdep.h,v $
- Revision 1.2.2.32  2005/12/30 17:40:22  dgrisby
- Previously extern inline functions are now just inline or static
- inline when inside classes.
+ Revision 1.5.2.9  2007/02/05 17:39:17  dgrisby
+ Later Sun compilers require a dummy return.
 
- Revision 1.2.2.31  2005/12/28 21:13:51  dgrisby
- Intel compiler on Windows supports constants in headers. Thanks Tim
- Theisen.
+ Revision 1.5.2.8  2007/01/12 10:19:51  dgrisby
+ Support for MontaVista ARM Linux.
 
- Revision 1.2.2.30  2005/12/15 17:12:21  dgrisby
- VC++ 7.1 doesn't properly support constants inside class
- declarations after all.
+ Revision 1.5.2.7  2006/04/28 18:40:46  dgrisby
+ Merge from omni4_0_develop.
 
- Revision 1.2.2.29  2005/10/13 11:37:07  dgrisby
- VC++ 8 doesn't like inline friend functions.
+ Revision 1.5.2.6  2006/01/10 12:24:04  dgrisby
+ Merge from omni4_0_develop pre 4.0.7 release.
 
- Revision 1.2.2.28  2005/07/22 09:52:59  dgrisby
- Remove more gcc warnings. Thanks Matej Kenda.
+ Revision 1.5.2.5  2005/11/17 17:03:27  dgrisby
+ Merge from omni4_0_develop.
 
- Revision 1.2.2.27  2005/07/21 15:53:02  dgrisby
- VC++ 7.1 supports constants in class declarations. Thanks Tim Theisen.
+ Revision 1.5.2.4  2005/07/22 17:18:40  dgrisby
+ Another merge from omni4_0_develop.
 
- Revision 1.2.2.26  2004/10/17 20:14:28  dgrisby
- Updated support for OpenVMS. Many thanks to Bruce Visscher.
+ Revision 1.5.2.3  2005/07/11 17:47:31  dgrisby
+ VMS changes from Bruce Visscher.
 
- Revision 1.2.2.25  2004/07/01 19:08:11  dgrisby
- Support Windows build with mingw. Thanks Wolfgang Glas.
+ Revision 1.5.2.2  2005/01/06 23:08:07  dgrisby
+ Big merge from omni4_0_develop.
 
- Revision 1.2.2.24  2003/05/09 13:29:59  dgrisby
- No inline friends in VC.NET 2003.
+ Revision 1.5.2.1  2003/03/23 21:04:22  dgrisby
+ Start of omniORB 4.1.x development branch.
 
  Revision 1.2.2.23  2003/03/02 17:10:40  dgrisby
  AIX patches integrated in main tree.
@@ -124,6 +121,19 @@
 #  define UnixArchitecture 1
 #endif
 
+//
+// Processor dependencies
+//
+
+#if defined(__arm__)
+#  if defined(__armv5teb__)
+#    define NO_OMNI_MIXED_ENDIAN_DOUBLE
+#  else
+#    define OMNI_MIXED_ENDIAN_DOUBLE
+#  endif
+#endif
+
+
 //
 // Macro to provide const_cast functionality on all platforms.
 //
@@ -150,6 +160,7 @@
 
 #if defined(__DECCXX)
 // DEC C++ compiler
+#  define NEED_DUMMY_RETURN
 #  if __DECCXX_VER < 60000000
 //    Compaq C++ 5.x
 //    Work-around for OpenVMS VAX Compaq C++ 5.6 compiler problem with
@@ -159,7 +170,6 @@
 #     ifdef __VMS
 #       pragma message disable CANTCOMPLETE
 #     endif
-#     define NEED_DUMMY_RETURN
 #     define OMNI_OPERATOR_REFPTR_REQUIRES_TYPEDEF
 #     define OMNI_PREMATURE_INSTANTIATION
 //    Extra macros from the Compaq C++ 5.x patch (in <top>/patches/) to be
@@ -172,9 +182,7 @@
 
 #if defined(__SUNPRO_CC) 
 // SUN C++ compiler
-#  if __SUNPRO_CC < 0x420
-#    define NEED_DUMMY_RETURN
-#  endif
+#  define NEED_DUMMY_RETURN
 
 // XXX
 // This is a hack to work around a bug in SUN C++ compiler (seen on 4.2).
