@@ -29,11 +29,29 @@
 
 /*
   $Log: minorCode.h,v $
-  Revision 1.1.4.17  2005/09/19 14:23:56  dgrisby
-  New traceFile configuration parameter.
+  Revision 1.1.6.7  2006/04/10 12:50:35  dgrisby
+  More endPointPublish; support for deprecated endPointNoListen,
+  endPointPublishAllIFs.
 
-  Revision 1.1.4.16  2004/05/05 21:04:01  dgrisby
-  Change COMMA define to avoid clashes with other systems.
+  Revision 1.1.6.6  2005/09/19 18:26:33  dgrisby
+  Merge from omni4_0_develop again.
+
+  Revision 1.1.6.5  2005/09/19 15:36:35  dgrisby
+  Refcount shortcut now throws INV_OBJREF when the servant is
+  deactivated, rather than deactivating the shortcut, which could lead
+  to a race condition.
+
+  Revision 1.1.6.4  2005/01/06 23:08:09  dgrisby
+  Big merge from omni4_0_develop.
+
+  Revision 1.1.6.3  2004/07/23 10:29:56  dgrisby
+  Completely new, much simpler Any implementation.
+
+  Revision 1.1.6.2  2003/05/20 16:53:12  dgrisby
+  Valuetype marshalling support.
+
+  Revision 1.1.6.1  2003/03/23 21:04:16  dgrisby
+  Start of omniORB 4.1.x development branch.
 
   Revision 1.1.4.15  2003/03/10 11:13:17  dgrisby
   BAD_PARAM with invalid fixed limits.
@@ -205,8 +223,16 @@ OMNI_NAMESPACE_BEGIN(omni)
 #define OMNIORBMinorCode_107 OMNIORBMinorCode(107)
 #define OMNIORBMinorCode_108 OMNIORBMinorCode(108)
 #define OMNIORBMinorCode_109 OMNIORBMinorCode(109)
-// Gap here to keep synchronisation with omniORB 4.1.x minor codes.
+#define OMNIORBMinorCode_110 OMNIORBMinorCode(110)
+#define OMNIORBMinorCode_111 OMNIORBMinorCode(111)
+#define OMNIORBMinorCode_112 OMNIORBMinorCode(112)
+#define OMNIORBMinorCode_113 OMNIORBMinorCode(113)
+#define OMNIORBMinorCode_114 OMNIORBMinorCode(114)
+#define OMNIORBMinorCode_115 OMNIORBMinorCode(115)
+#define OMNIORBMinorCode_116 OMNIORBMinorCode(116)
+#define OMNIORBMinorCode_117 OMNIORBMinorCode(117)
 #define OMNIORBMinorCode_118 OMNIORBMinorCode(118)
+#define OMNIORBMinorCode_119 OMNIORBMinorCode(119)
 
 #define OMNI_COMMA ,
 #define DeclareValue(name,value) name = value
@@ -290,7 +316,8 @@ code( BAD_PARAM_EmbeddedNullInPythonString   , OMNIORBMinorCode_96 ) sep \
 code( BAD_PARAM_StringIsTooLong              , OMNIORBMinorCode_100 ) sep \
 code( BAD_PARAM_SequenceIsTooLong            , OMNIORBMinorCode_101 ) sep \
 code( BAD_PARAM_WrongUnionMemberSelected     , OMNIORBMinorCode_107 ) sep \
-code( BAD_PARAM_InvalidFixedPointLimits      , OMNIORBMinorCode_109 )
+code( BAD_PARAM_InvalidFixedPointLimits      , OMNIORBMinorCode_109 ) sep \
+code( BAD_PARAM_AttemptToMarshalAbstractValue, OMNIORBMinorCode_115 )
 
 
 enum BAD_PARAM_minor {
@@ -315,7 +342,8 @@ code( INV_OBJREF_TryToInvokePseudoRemotely, OMNIORBMinorCode_23 ) sep \
 code( INV_OBJREF_InvokeOnNilObjRef  	  , OMNIORBMinorCode_48 ) sep \
 code( INV_OBJREF_CorruptedObjRef    	  , OMNIORBMinorCode_54 ) sep \
 code( INV_OBJREF_InterfaceMisMatch  	  , OMNIORBMinorCode_55 ) sep \
-code( INV_OBJREF_NoPythonTypeForPseudoObj , OMNIORBMinorCode_104 )
+code( INV_OBJREF_NoPythonTypeForPseudoObj , OMNIORBMinorCode_104 ) sep \
+code( INV_OBJREF_ShortcutServantDeactivated,OMNIORBMinorCode_117 )
 
 
  
@@ -350,7 +378,12 @@ code( MARSHAL_ExceptionInDSINotPropagated     , OMNIORBMinorCode_67 ) sep \
 code( MARSHAL_InvalidContextList              , OMNIORBMinorCode_79 ) sep \
 code( MARSHAL_InvalidIndirection              , OMNIORBMinorCode_90 ) sep \
 code( MARSHAL_InvalidTypeCodeKind             , OMNIORBMinorCode_91 ) sep \
-code( MARSHAL_MessageTooLong                  , OMNIORBMinorCode_93 )
+code( MARSHAL_MessageTooLong                  , OMNIORBMinorCode_93 ) sep \
+code( MARSHAL_CannotReserveOutputSpace        , OMNIORBMinorCode_110 ) sep \
+code( MARSHAL_InvalidChunkedEncoding          , OMNIORBMinorCode_111 ) sep \
+code( MARSHAL_InvalidValueTag                 , OMNIORBMinorCode_112 ) sep \
+code( MARSHAL_NoRepoIdInValueType             , OMNIORBMinorCode_113 ) sep \
+code( MARSHAL_TypeIsNotAValueType             , OMNIORBMinorCode_114 )
 
 
 
@@ -367,7 +400,8 @@ code( BAD_TYPECODE_TypeCodeIsNil     	, OMNIORBMinorCode_71 ) sep \
 code( BAD_TYPECODE_InvalidOperation  	, OMNIORBMinorCode_89 ) sep \
 code( BAD_TYPECODE_UnknownKind          , OMNIORBMinorCode_94 ) sep \
 code( BAD_TYPECODE_UnresolvedRecursiveTC, OMNIORBMinorCode_105 ) sep \
-code( BAD_TYPECODE_InvalidIndirection   , OMNIORBMinorCode_108 )
+code( BAD_TYPECODE_InvalidIndirection   , OMNIORBMinorCode_108 ) sep \
+code( BAD_TYPECODE_NotEquivalent        , OMNIORBMinorCode_116 )
 
 enum BAD_TYPECODE_minor {
   DECLARE_BAD_TYPECODE_minors(DeclareValue,OMNI_COMMA)  
@@ -538,15 +572,16 @@ enum INTF_REPOS_minor {
 // INITIALIZE
 #define DECLARE_INITIALIZE_minors(code,sep) \
 \
-code( INITIALIZE_TransportError       , OMNIORBMinorCode_13 ) sep \
-code( INITIALIZE_InvalidORBInitArgs   , OMNIORBMinorCode_30 ) sep \
-code( INITIALIZE_FailedBOAInit        , OMNIORBMinorCode_31 ) sep \
-code( INITIALIZE_FailedPOAInit        , OMNIORBMinorCode_32 ) sep \
-code( INITIALIZE_FailedORBInit        , OMNIORBMinorCode_44 ) sep \
-code( INITIALIZE_FailedLoadLibrary    , OMNIORBMinorCode_45 ) sep \
-code( INITIALIZE_ConfigFileError      , OMNIORBMinorCode_50 ) sep \
-code( INITIALIZE_NotOmniThread        , OMNIORBMinorCode_56 ) sep \
-code( INITIALIZE_CannotOpenLogFile    , OMNIORBMinorCode_118 )
+code( INITIALIZE_TransportError        , OMNIORBMinorCode_13 ) sep \
+code( INITIALIZE_InvalidORBInitArgs    , OMNIORBMinorCode_30 ) sep \
+code( INITIALIZE_FailedBOAInit         , OMNIORBMinorCode_31 ) sep \
+code( INITIALIZE_FailedPOAInit         , OMNIORBMinorCode_32 ) sep \
+code( INITIALIZE_FailedORBInit         , OMNIORBMinorCode_44 ) sep \
+code( INITIALIZE_FailedLoadLibrary     , OMNIORBMinorCode_45 ) sep \
+code( INITIALIZE_ConfigFileError       , OMNIORBMinorCode_50 ) sep \
+code( INITIALIZE_NotOmniThread         , OMNIORBMinorCode_56 ) sep \
+code( INITIALIZE_CannotOpenLogFile     , OMNIORBMinorCode_118 ) sep \
+code( INITIALIZE_EndpointPublishFailure, OMNIORBMinorCode_119 )
 
 
 enum INITIALIZE_minor {
