@@ -29,18 +29,17 @@
 
 /*
   $Log: wstringtypes.h,v $
-  Revision 1.1.2.14  2005/10/11 13:17:01  dgrisby
-  Win64 support, thanks Peter Klotz. sizeof(long) < sizeof(void*) !!
+  Revision 1.1.4.4  2005/11/17 17:03:27  dgrisby
+  Merge from omni4_0_develop.
 
-  Revision 1.1.2.13  2005/03/14 13:39:51  dgrisby
-  Avoid compiler warnings about empty for loop.
+  Revision 1.1.4.3  2005/03/30 23:36:14  dgrisby
+  Another merge from omni4_0_develop.
 
-  Revision 1.1.2.12  2004/04/30 15:58:33  dgrisby
-  Make ptr_arith_t unsigned.
+  Revision 1.1.4.2  2005/01/06 23:08:22  dgrisby
+  Big merge from omni4_0_develop.
 
-  Revision 1.1.2.11  2003/11/06 10:17:36  dgrisby
-  Remove calls to strlen in operator[]. Why were they ever considered a
-  good idea?
+  Revision 1.1.4.1  2003/03/23 21:03:58  dgrisby
+  Start of omniORB 4.1.x development branch.
 
   Revision 1.1.2.10  2003/01/16 12:47:08  dgrisby
   Const cast macro. Thanks Matej Kenda.
