@@ -133,6 +133,9 @@ class omni_thread;
 #elif defined(__linux__)
 #include <omnithread/posix.h>
 
+#elif defined(__GLIBC__)
+#include <omnithread/posix.h>
+
 #elif defined(__nextstep__)
 #include <omnithread/mach.h>
 
@@ -154,6 +157,12 @@ class omni_thread;
 #elif defined(__freebsd__)
 #include <omnithread/posix.h>
 
+#elif defined(__netbsd__)
+#include <omnithread/posix.h>
+
+#elif defined(__openbsd__)
+#include <omnithread/posix.h>
+
 #elif defined(__rtems__)
 #include <omnithread/posix.h>
 #include <sched.h>
@@ -165,6 +174,9 @@ class omni_thread;
 #include <omnithread/posix.h>
 #include <sched.h>
 
+#elif defined(__cygwin__)
+#include <omnithread/posix.h>
+
 #else
 #error "No implementation header file"
 #endif
@@ -254,8 +266,8 @@ OMNI_THREAD_EXPOSE:
 class _OMNITHREAD_NTDLL_ omni_mutex_lock {
     omni_mutex& mutex;
 public:
-    omni_mutex_lock(omni_mutex& m) : mutex(m) { mutex.lock(); }
-    ~omni_mutex_lock(void) { mutex.unlock(); }
+    inline omni_mutex_lock(omni_mutex& m) : mutex(m) { mutex.lock(); }
+    inline ~omni_mutex_lock(void) { mutex.unlock(); }
 private:
     // dummy copy constructor and operator= to prevent copying
     omni_mutex_lock(const omni_mutex_lock&);
@@ -421,8 +433,8 @@ protected:
 
     virtual ~omni_thread(void);
 	// destructor cannot be called by user (except via a derived class).
-	// Use exit() or cancel() instead. This also means a thread object must
-	// be allocated with new - it cannot be statically or automatically
+	// Use exit() instead. This also means a thread object must be
+	// allocated with new - it cannot be statically or automatically
 	// allocated. The destructor of a class that inherits from omni_thread
 	// shouldn't be public either (otherwise the thread object can be
 	// destroyed while the underlying thread is still running).
