@@ -29,21 +29,40 @@
 
 /*
   $Log: GIOP_S.cc,v $
-  Revision 1.1.4.29  2005/11/15 11:07:57  dgrisby
-  More shutdown cleanup.
+  Revision 1.1.6.11  2007/04/05 15:37:32  dgrisby
+  Minor fix to log message formatting.
 
-  Revision 1.1.4.28  2005/04/08 00:06:15  dgrisby
-  Remove all remaining uses of logf.
+  Revision 1.1.6.10  2007/04/05 15:05:24  dgrisby
+  Finished call could be selected by a CancelRequest, leading to an
+  infinite loop failing to handle it.
 
-  Revision 1.1.4.27  2005/01/04 18:09:29  dgrisby
-  SkipRequestBody did not call notifyWkPreUpCall, which meant requests
-  would be mislaid if they came in the same buffer as a skipped request.
+  Revision 1.1.6.9  2006/11/09 15:36:17  dgrisby
+  Code formatting fix.
 
-  Revision 1.1.4.26  2004/10/17 21:48:38  dgrisby
-  Support CancelRequest better.
+  Revision 1.1.6.8  2006/08/07 13:49:13  dgrisby
+  Allow serverReceiveRequest interceptor to throw user exceptions.
 
-  Revision 1.1.4.25  2003/07/16 14:22:38  dgrisby
-  Speed up oneway handling a little. More tracing for split messages.
+  Revision 1.1.6.7  2006/07/02 22:52:05  dgrisby
+  Store self thread in task objects to avoid calls to self(), speeding
+  up Current. Other minor performance tweaks.
+
+  Revision 1.1.6.6  2005/11/17 17:03:26  dgrisby
+  Merge from omni4_0_develop.
+
+  Revision 1.1.6.5  2005/04/08 00:35:46  dgrisby
+  Merging again.
+
+  Revision 1.1.6.4  2005/01/06 23:10:11  dgrisby
+  Big merge from omni4_0_develop.
+
+  Revision 1.1.6.3  2003/11/06 11:56:56  dgrisby
+  Yet more valuetype. Plain valuetype and abstract valuetype are now working.
+
+  Revision 1.1.6.2  2003/05/20 16:53:15  dgrisby
+  Valuetype marshalling support.
+
+  Revision 1.1.6.1  2003/03/23 21:02:32  dgrisby
+  Start of omniORB 4.1.x development branch.
 
   Revision 1.1.4.24  2002/11/26 16:54:34  dgrisby
   Fix exception interception.
@@ -223,6 +242,8 @@ GIOP_S::dispatcher() {
   try {
 
     pd_state = WaitForRequestHeader;
+    calldescriptor(0);
+    requestId(0xffffffff);
 
     impl()->inputMessageBegin(this,impl()->unmarshalWildCardRequestHeader);
 
@@ -232,10 +253,7 @@ GIOP_S::dispatcher() {
       if (!pd_strand->stopIdleCounter()) {
 	// This strand has been expired by the scavenger. Don't
 	// process this call.
-	if (omniORB::trace(1)) {
-	  omniORB::logger l;
-	  l << "dispatcher cannot stop idle counter.\n";
-	}
+	omniORB::logs(1, "dispatcher cannot stop idle counter.\n");
 	pd_strand->state(giopStrand::DYING);
 	return 0;
       }
@@ -254,7 +272,7 @@ GIOP_S::dispatcher() {
       if( omniORB::trace(1) ) {
 	omniORB::logger l;
 	l << "Unexpected message type (" << (CORBA::ULong) pd_requestType
-	  << ")received by a server thread at "
+	  << ") received by a server thread at "
 	  << __FILE__ << ": line " << __LINE__ << "\n";
       }
       return 0;
@@ -299,7 +317,7 @@ GIOP_S::handleRequest() {
     }
 
     // Create a callHandle object
-    omniCallHandle call_handle(this);
+    omniCallHandle call_handle(this, pd_worker->selfThread());
 
     // Can we find the object in the local object table?
     if (keysize() < 0)
@@ -371,7 +389,8 @@ GIOP_S::handleRequest() {
   }
 
 #define MARSHAL_USER_EXCEPTION() do { \
-      OMNIORB_ASSERT(calldescriptor() != 0); \
+  if (response_expected()) { \
+    if (calldescriptor()) { \
       int i, repoid_size;  \
       const char* repoid = ex._NP_repoId(&repoid_size); \
       for( i = 0; i < pd_n_user_excns; i++ ) \
@@ -390,6 +409,14 @@ GIOP_S::handleRequest() {
 			   (CORBA::CompletionStatus) completion()); \
 	impl()->sendSystemException(this,sex); \
       } \
+    } \
+    else { \
+      impl()->sendUserException(this,ex); \
+    } \
+  } \
+  if (pd_state == RequestIsBeingProcessed) { \
+    SkipRequestBody(); \
+  } \
 } while (0)
 
 #define MARSHAL_SYSTEM_EXCEPTION() do { \
@@ -420,11 +447,9 @@ GIOP_S::handleRequest() {
 #    undef CATCH_AND_MARSHAL
 
   catch(omniORB::StubUserException& uex) {
-    if (response_expected()) {
-      CORBA::UserException& ex = *((CORBA::UserException*)uex.ex());
-      MARSHAL_USER_EXCEPTION();
-      delete uex.ex();  // ?? Possible memory leak?
-    }
+    CORBA::UserException& ex = *((CORBA::UserException*)uex.ex());
+    MARSHAL_USER_EXCEPTION();
+    delete uex.ex();  // ?? Possible memory leak?
   }
 
 #endif
@@ -436,9 +461,7 @@ GIOP_S::handleRequest() {
     // the system exception.
   }
   catch(CORBA::UserException& ex) {
-    if (response_expected()) {
-      MARSHAL_USER_EXCEPTION();
-    }
+    MARSHAL_USER_EXCEPTION();
   }
 #undef MARSHAL_USER_EXCEPTION
 #undef MARSHAL_SYSTEM_EXCEPTION
@@ -453,9 +476,11 @@ GIOP_S::handleRequest() {
       l << "WARNING -- method \'" << operation() << "\' raised an unexpected\n"
 	" exception (not a CORBA exception).\n";
     }
-    CORBA::UNKNOWN ex(UNKNOWN_UserException,
-		      (CORBA::CompletionStatus) completion());
-    impl()->sendSystemException(this,ex);
+    if (response_expected()) {
+      CORBA::UNKNOWN ex(UNKNOWN_UserException,
+			(CORBA::CompletionStatus) completion());
+      impl()->sendSystemException(this,ex);
+    }
   }
   pd_state = ReplyCompleted;
   return 1;
@@ -598,6 +623,8 @@ GIOP_S::ReceiveRequest(omniCallDescriptor& desc) {
   desc.unmarshalArguments(s);
   pd_state = WaitingForReply;
 
+  clearValueTracker();
+
   // Here we notify the giopServer that this thread has finished
   // reading the request. The server may want to keep a watch on
   // any more request coming in on the connection while this
@@ -672,6 +699,8 @@ GIOP_S::SendReply() {
   calldescriptor()->marshalReturnedValues(s);
   impl()->outputMessageEnd(this);
   pd_state = ReplyCompleted;
+
+  clearValueTracker();
 }
 
 ////////////////////////////////////////////////////////////////////////
@@ -702,6 +731,8 @@ GIOP_S::SendException(CORBA::Exception* ex) {
   // handleRequest.
   impl()->sendUserException(this,*((CORBA::UserException*)ex));
   pd_state = ReplyCompleted;
+
+  clearValueTracker();
 }
 
 ////////////////////////////////////////////////////////////////////////
@@ -793,7 +824,7 @@ GIOP_S::unmarshalIORAddressingInfo() {
 
     IIOP::ProfileBody decodedBody;
     IIOP::unmarshalProfile(ta.ior.profiles[ta.selected_profile_index],
-			decodedBody);
+			   decodedBody);
 
 #if 0 // XXX Not finalise yet
     _OMNI_NS(giopAddressList) addresses;
