@@ -31,6 +31,9 @@
 
 /*
   $Log: SocketCollection.cc,v $
+  Revision 1.1.4.23  2007/12/09 01:35:08  dgrisby
+  Race condition between Peek / select thread when data in buffer.
+
   Revision 1.1.4.22  2007/07/04 09:13:32  dgrisby
   Condition variable used in Peek() was leaked.
 
@@ -644,8 +647,8 @@ SocketHolder::setSelectable(int            now,
     }
   }
 
-  pd_selectable      = 1;
-  pd_data_in_buffer |= data_in_buffer;
+  pd_selectable     = 1;
+  pd_data_in_buffer = pd_data_in_buffer || data_in_buffer;
 
   pd_belong_to->pd_changed = 1;
 
@@ -656,7 +659,7 @@ SocketHolder::setSelectable(int            now,
 
 #ifdef UnixArchitecture
   if (!hold_lock &&
-      (now || pd_data_in_buffer || pd_belong_to->pd_idle_count == 0)) {
+      (now || pd_belong_to->pd_idle_count == 0)) {
 
     // Wake up the Select thread by writing to the pipe.
     if (pd_belong_to->pd_pipe_write >= 0 && !pd_belong_to->pd_pipe_full) {
@@ -1033,8 +1036,8 @@ SocketHolder::setSelectable(int            now,
     }
   }
 
-  pd_selectable      = 1;
-  pd_data_in_buffer |= data_in_buffer;
+  pd_selectable     = 1;
+  pd_data_in_buffer = pd_data_in_buffer || data_in_buffer;
 
   pd_belong_to->pd_changed = 1;
 
@@ -1394,8 +1397,8 @@ SocketHolder::setSelectable(int            now,
     }
   }
 
-  pd_selectable      = 1;
-  pd_data_in_buffer |= data_in_buffer;
+  pd_selectable     = 1;
+  pd_data_in_buffer = pd_data_in_buffer || data_in_buffer;
 
   pd_belong_to->pd_changed = 1;
 
@@ -1406,7 +1409,7 @@ SocketHolder::setSelectable(int            now,
 
 #ifdef UnixArchitecture
   if (!hold_lock &&
-      (now || pd_data_in_buffer || pd_belong_to->pd_idle_count == 0)) {
+      (now || pd_belong_to->pd_idle_count == 0)) {
 
     // Wake up the Select thread by writing to the pipe.
     if (pd_belong_to->pd_pipe_write >= 0 && !pd_belong_to->pd_pipe_full) {
