@@ -29,26 +29,27 @@
 
 /*
   $Log: corbaOrb.cc,v $
-  Revision 1.33.2.48  2005/11/28 14:57:51  dgrisby
-  New abortOnNativeException parameter for Windows.
+  Revision 1.36.2.7  2007/04/12 14:53:31  dgrisby
+  Output omniORB version number in log.
 
-  Revision 1.33.2.47  2005/09/08 14:26:17  dgrisby
-  New -ORBconfigFile command line argument.
+  Revision 1.36.2.6  2006/05/02 13:08:26  dgrisby
+  Time out waiting for invoker threads to exit; allow configutation of
+  idle thread timeout.
 
-  Revision 1.33.2.46  2005/03/14 13:36:02  dgrisby
-  Call detach() not attach() on shutdown!
+  Revision 1.36.2.5  2006/01/10 12:24:03  dgrisby
+  Merge from omni4_0_develop pre 4.0.7 release.
 
-  Revision 1.33.2.45  2003/08/21 14:57:44  dgrisby
-  Really silly bug broke registry reading on Windows.
+  Revision 1.36.2.4  2005/09/08 14:49:40  dgrisby
+  Merge -ORBconfigFile argument.
 
-  Revision 1.33.2.44  2003/07/30 14:23:35  dgrisby
-  Fix various race conditions in ORB shutdown.
+  Revision 1.36.2.3  2005/03/30 23:36:10  dgrisby
+  Another merge from omni4_0_develop.
 
-  Revision 1.33.2.43  2003/06/02 13:26:59  dgrisby
-  Configuration dump error on some platforms.
+  Revision 1.36.2.2  2005/01/06 23:10:12  dgrisby
+  Big merge from omni4_0_develop.
 
-  Revision 1.33.2.42  2003/05/27 11:20:44  dgrisby
-  For some reason the config file was not looked at on Windows.
+  Revision 1.36.2.1  2003/03/23 21:02:22  dgrisby
+  Start of omniORB 4.1.x development branch.
 
   Revision 1.33.2.41  2002/09/09 00:24:40  dgrisby
   Make sure various modules initialise. Needed by MacOSX.
@@ -438,6 +439,7 @@ extern omniInitialiser& omni_ObjRef_initialiser_;
 extern omniInitialiser& omni_orbOptions_initialiser_;
 extern omniInitialiser& omni_poa_initialiser_;
 extern omniInitialiser& omni_uri_initialiser_;
+extern omniInitialiser& omni_invoker_initialiser_;
 
 OMNI_NAMESPACE_END(omni)
 
@@ -527,12 +529,12 @@ CORBA::ORB_init(int& argc, char** argv, const char* orb_identifier,
     return the_orb;
   }
 
-  const char* option_src_1 = "configuration file";
-  const char* option_src_2 = "environment variable";
-  const char* option_src_3 = "argument";
-  const char* option_src_4 = "option list";
-  const char* option_src_5 = "-ORB arguments";
-  const char* option_source= 0;
+  const char* option_src_1  = "configuration file";
+  const char* option_src_2  = "environment variable";
+  const char* option_src_3  = "argument";
+  const char* option_src_4  = "option list";
+  const char* option_src_5  = "-ORB arguments";
+  const char* option_source = 0;
   try {
 
     orbOptions::singleton().reset();
@@ -624,11 +626,8 @@ CORBA::ORB_init(int& argc, char** argv, const char* orb_identifier,
 		  CORBA::COMPLETED_NO);
   }
 
-
-  if (omniORB::trace(2)) {
-    omniORB::logger l;
-    l << "Distribution date: " OMNIORB_DIST_DATE "\n";
-  }
+  omniORB::logs(2, "Version: " OMNIORB_VERSION_STRING);
+  omniORB::logs(2, "Distribution date: " OMNIORB_DIST_DATE);
 
   try {
     // Call attach method of each initialiser object.
@@ -657,6 +656,7 @@ CORBA::ORB_init(int& argc, char** argv, const char* orb_identifier,
     omni_orbOptions_initialiser_.attach();
     omni_poa_initialiser_.attach();
     omni_uri_initialiser_.attach();
+    omni_invoker_initialiser_.attach();
     omni_hooked_initialiser_.attach();
 
     if (orbParameters::lcdMode) {
@@ -897,6 +897,7 @@ omniOrbORB::destroy()
 
     // Call detach method of the initialisers in reverse order.
     omni_hooked_initialiser_.detach();
+    omni_invoker_initialiser_.detach();
     omni_uri_initialiser_.detach();
     omni_poa_initialiser_.detach();
     omni_orbOptions_initialiser_.detach();
