@@ -29,6 +29,33 @@
 
 /*
   $Log: giopBiDir.cc,v $
+  Revision 1.1.4.9  2006/06/22 13:53:49  dgrisby
+  Add flags to strand.
+
+  Revision 1.1.4.8  2006/06/05 11:28:04  dgrisby
+  Change clientSendRequest interceptor members to a single GIOP_C.
+
+  Revision 1.1.4.7  2006/06/02 12:48:32  dgrisby
+  Small code cleanups.
+
+  Revision 1.1.4.6  2006/04/09 19:52:31  dgrisby
+  More IPv6, endPointPublish parameter.
+
+  Revision 1.1.4.5  2006/01/10 13:59:37  dgrisby
+  New clientConnectTimeOutPeriod configuration parameter.
+
+  Revision 1.1.4.4  2005/03/02 13:33:42  dgrisby
+  Variable name clash.
+
+  Revision 1.1.4.3  2005/03/02 12:39:18  dgrisby
+  Merge from omni4_0_develop.
+
+  Revision 1.1.4.2  2005/01/06 23:10:15  dgrisby
+  Big merge from omni4_0_develop.
+
+  Revision 1.1.4.1  2003/03/23 21:02:17  dgrisby
+  Start of omniORB 4.1.x development branch.
+
   Revision 1.1.2.15  2003/02/03 16:53:14  dgrisby
   Force type in constructor argument to help confused compilers.
 
@@ -85,6 +112,7 @@
 #include <omniORB4/minorCode.h>
 #include <omniORB4/omniInterceptors.h>
 #include <omniORB4/objTracker.h>
+#include <omniORB4/callDescriptor.h>
 #include <exceptiondefs.h>
 #include <giopStrand.h>
 #include <giopRope.h>
@@ -103,15 +131,6 @@
 
 OMNI_USING_NAMESPACE(omni)
 
-// XXX To-do
-// a) BiDirServerRope garbage collection. At the moment, the server
-//    side of a bidirectional connection is garbage collected in
-//    the same way as an ordinary connection. That is, it is closed after
-//    a period of inactivity. In fact, the connection should only be closed
-//    if all the object references unmarshal from the connection have
-//    been released. In other words, the reference count on the
-//    BiDirServerRope instance attached to the connection == 0.
-
 ////////////////////////////////////////////////////////////////////////////
 //             Configuration options                                      //
 ////////////////////////////////////////////////////////////////////////////
@@ -242,6 +261,18 @@ BiDirServerRope::BiDirServerRope(giopStrand* strand, giopAddress* addr) :
   strand->RopeLink::insert(pd_strands);
 }
 
+////////////////////////////////////////////////////////////////////////
+BiDirServerRope::~BiDirServerRope()
+{
+  giopAddressList::const_iterator i, last;
+  i    = pd_redirect_addresses.begin();
+  last = pd_redirect_addresses.end();
+  for (; i != last; i++) {
+    delete (*i);
+  }
+}
+
+
 ////////////////////////////////////////////////////////////////////////
 BiDirServerRope*
 BiDirServerRope::addRope(giopStrand* strand, const giopAddressList& addrlist) {
@@ -361,7 +392,7 @@ CORBA::Boolean
 BiDirServerRope::match(const char* sendfrom,
 		       const giopAddressList& addrlist) const {
 
-  if (strcmp(pd_sendfrom,sendfrom) != 0) return 0;
+  if (!omni::strMatch(pd_sendfrom,sendfrom)) return 0;
 
   giopAddressList::const_iterator i, last;
   i    = addrlist.begin();
@@ -453,6 +484,20 @@ BiDirServerRope::decrRefCount() {
     RopeLink::remove();
     delete this;
   }
+  else {
+    RopeLink* p = pd_strands.next;
+    for (; p != &pd_strands; p = p->next) {
+      giopStrand* g = (giopStrand*)p;
+      if (g->state() != giopStrand::DYING) {
+	if (omniORB::trace(30)) {
+	  omniORB::logger l;
+	  l << "Bi-directional rope is no longer referenced; strand "
+	    << (void*)g << " is a candidate for scavenging.\n";
+	}
+	g->startIdleCounter();
+      }
+    }
+  }
 }
 
 
@@ -485,19 +530,60 @@ BiDirClientRope::acquireClient(const omniIOR* ior,
 
   GIOP_C* giop_c = (GIOP_C*) giopRope::acquireClient(ior,key,keysize,calldesc);
 
+  // Bidirectional is only supported in GIOP 1.2 and above
+  GIOP::Version v = ior->getIORInfo()->version();
+  if (!(v.major > 1 || v.minor >= 2)) {
+    if (omniORB::trace(20)) {
+      omniORB::logger log;
+      log << "Bidirectional client using normal connection because "
+	  << "it is only GIOP " << (int)v.major << "." << (int)v.minor << "\n";
+    }
+    return giop_c;
+  }
+
   omni_tracedmutex_lock sync(pd_lock);
   giopStrand& s = (giopStrand&)((giopStream&)(*giop_c));
   if (s.connection == 0 && s.state() != giopStrand::DYING) {
-    unsigned long deadline_secs,deadline_nanosecs;
-    giop_c->getDeadline(deadline_secs,deadline_nanosecs);
+    if (omniORB::trace(20)) {
+      omniORB::logger log;
+      log << "Bidirectional client attempt to connect to "
+	  << s.address->address() << "\n";
+    }
+    unsigned long s_deadline_secs, s_deadline_nanosecs;
+    giop_c->getDeadline(s_deadline_secs,s_deadline_nanosecs);
+
+    unsigned long deadline_secs, deadline_nanosecs;
+    if (orbParameters::clientConnectTimeOutPeriod.secs ||
+	orbParameters::clientConnectTimeOutPeriod.nanosecs) {
+
+      omni_thread::
+	get_time(&deadline_secs,
+		 &deadline_nanosecs,
+		 orbParameters::clientConnectTimeOutPeriod.secs,
+		 orbParameters::clientConnectTimeOutPeriod.nanosecs);
+
+      if ((s_deadline_secs && deadline_secs > s_deadline_secs) ||
+	  (deadline_secs == s_deadline_secs &&
+	   deadline_nanosecs > s_deadline_nanosecs)) {
+
+	giop_c->setDeadline(deadline_secs, deadline_nanosecs);
+	calldesc->setDeadline(deadline_secs, deadline_nanosecs);
+      }
+    }
+    else {
+      deadline_secs     = s_deadline_secs;
+      deadline_nanosecs = s_deadline_nanosecs;
+    }
+
     giopActiveConnection* c = s.address->Connect(deadline_secs,
-						 deadline_nanosecs);
+						 deadline_nanosecs,
+						 s.flags);
     if (c) s.connection = &(c->getConnection());
     if (!s.connection) {
       s.state(giopStrand::DYING);
     }
     else {
-      // now make the connection manage by the giopServer.
+      // now make the connection managed by the giopServer.
       s.biDir = 1;
       s.gatekeeper_checked = 1;
       giopActiveCollection* watcher = c->registerMonitor();
@@ -528,7 +614,8 @@ BiDirClientRope::acquireClient(const omniIOR* ior,
 /////////////////////////////////////////////////////////////////////////////
 static
 CORBA::Boolean
-getBiDirServiceContext(omniInterceptors::serverReceiveRequest_T::info_T& info) {
+getBiDirServiceContext(omniInterceptors::serverReceiveRequest_T::info_T& info)
+{
 
   if (!orbParameters::acceptBiDirectionalGIOP) {
     // XXX If the ORB policy is "don't support bidirectional", don't bother 
@@ -541,7 +628,8 @@ getBiDirServiceContext(omniInterceptors::serverReceiveRequest_T::info_T& info) {
   giopStrand& strand = (giopStrand&)((giopStream&)info.giop_s);
 
   if (ver.minor != 2 || strand.isClient()) {
-    // Only parse service context if the GIOP version is 1.2, on the server side
+    // Only parse service context if the GIOP version is 1.2, on the
+    // server side
     return 1;
   }
 
@@ -663,7 +751,13 @@ getBiDirServiceContext(omniInterceptors::serverReceiveRequest_T::info_T& info) {
 	}
 
 	BiDirServerRope* r = BiDirServerRope::addRope(&strand,addrList);
-
+      }
+      
+      giopAddressList::const_iterator addr, last;
+      addr = addrList.begin();
+      last = addrList.end();
+      for (; addr != last; addr++) {
+	delete (*addr);
       }
     }
   }
@@ -683,8 +777,8 @@ setBiDirServiceContext(omniInterceptors::clientSendRequest_T::info_T& info) {
     return 1;
   }
 
-  giopStrand& g = (giopStrand&)(info.giopstream);
-  GIOP::Version ver = info.giopstream.version();
+  giopStrand& g = (giopStrand&)info.giop_c;
+  GIOP::Version ver = info.giop_c.version();
 
   if (ver.minor != 2 || !g.biDir || !g.isClient() || g.biDir_initiated) {
     // Only send service context if the GIOP version is 1.2, this is
@@ -693,20 +787,17 @@ setBiDirServiceContext(omniInterceptors::clientSendRequest_T::info_T& info) {
     return 1;
   }
 
-  const omnivector<const char*>& epts = omniObjAdapter::listMyEndpoints();
-  omnivector<const char*>::const_iterator i = epts.begin();
-  omnivector<const char*>::const_iterator last = epts.end();
+  const orbServer::EndpointList& epts = omniObjAdapter::listMyEndpoints();
+  CORBA::ULong el = epts.length();
 
-  ListenPointList l(epts.size());
+  ListenPointList l(el);
   CORBA::ULong j = 0;
-  for ( ; i != last; i++) {
-    if (strncmp((*i),"giop:tcp",8) == 0 || strncmp((*i),"giop:ssl",8) == 0) {
-      const char* p = strchr((*i),':');
-      OMNIORB_ASSERT(p);
-      p = strchr(p+1,':');
-      OMNIORB_ASSERT(p);
+
+  for (CORBA::ULong i=0 ; i != el; i++) {
+    const char* ep = epts[i];
+    if (strncmp(ep,"giop:tcp:",9) == 0 || strncmp(ep,"giop:ssl:",9) == 0) {
       l.length(j+1);
-      if (!tcpTransportImpl::parseAddress(p+1,l[j])) OMNIORB_ASSERT(0);
+      if (!tcpTransportImpl::parseAddress(ep+9, l[j++])) OMNIORB_ASSERT(0);
     }
   }
   if (l.length()) {
@@ -724,7 +815,7 @@ setBiDirServiceContext(omniInterceptors::clientSendRequest_T::info_T& info) {
 
     if (omniORB::trace(25)) {
       omniORB::logger log;
-      log << " send bidir IIOP service context: ( ";
+      log << "Send bidir IIOP service context: ( ";
 
       for (CORBA::ULong i = 0; i < l.length(); i++) {
 	log << (const char*) l[i].host << ":" << l[i].port << " ";
