@@ -29,17 +29,20 @@
 
 /*
   $Log: giopEndpoint.cc,v $
-  Revision 1.1.2.17  2005/09/05 14:31:08  dgrisby
-  SSL transport extensions from Jon Biggar; SSL command line options.
+  Revision 1.1.4.5  2006/04/09 19:52:31  dgrisby
+  More IPv6, endPointPublish parameter.
 
-  Revision 1.1.2.16  2004/02/11 18:33:20  dgrisby
-  Windows / MSVC 7 fixes.
+  Revision 1.1.4.4  2006/03/25 18:54:03  dgrisby
+  Initial IPv6 support.
 
-  Revision 1.1.2.15  2003/11/06 10:19:19  dgrisby
-  Remove transports from linked list when they are deleted.
+  Revision 1.1.4.3  2005/09/05 17:12:20  dgrisby
+  Merge again. Mainly SSL transport changes.
 
-  Revision 1.1.2.14  2003/05/22 13:41:41  dgrisby
-  HPUX patches.
+  Revision 1.1.4.2  2005/01/06 23:10:15  dgrisby
+  Big merge from omni4_0_develop.
+
+  Revision 1.1.4.1  2003/03/23 21:02:16  dgrisby
+  Start of omniORB 4.1.x development branch.
 
   Revision 1.1.2.13  2002/09/08 21:58:55  dgrisby
   Support for MSVC 7. (Untested.)
@@ -88,6 +91,7 @@
 #include <omniORB4/CORBA.h>
 #include <omniORB4/omniTransport.h>
 #include <omniORB4/giopEndpoint.h>
+#include <omniORB4/omniURI.h>
 #include <omniORB4/linkHacks.h>
 #include <initialiser.h>
 #include <orbOptions.h>
@@ -181,28 +185,18 @@ giopAddress::str2Address(const char* address) {
 ////////////////////////////////////////////////////////////////////////
 giopAddress*
 giopAddress::fromTcpAddress(const IIOP::Address& addr) {
-  const char* format = "giop:tcp:%s:%d";
 
-  CORBA::ULong len = strlen(addr.host);
-  if (len == 0) return 0;
-  len += strlen(format) + 6;
-  CORBA::String_var addrstr;
-  addrstr = CORBA::string_alloc(len);
-  sprintf(addrstr,format,(const char*)addr.host,addr.port);
+  CORBA::String_var addrstr = omniURI::buildURI("giop:tcp:",
+						addr.host, addr.port);
   return giopAddress::str2Address(addrstr);
 }
 
 ////////////////////////////////////////////////////////////////////////
 giopAddress*
 giopAddress::fromSslAddress(const IIOP::Address& addr) {
-  const char* format = "giop:ssl:%s:%d";
 
-  CORBA::ULong len = strlen(addr.host);
-  if (len == 0) return 0;
-  len += strlen(format) + 6;
-  CORBA::String_var addrstr;
-  addrstr = CORBA::string_alloc(len);
-  sprintf(addrstr,format,(const char*)addr.host,addr.port);
+  CORBA::String_var addrstr = omniURI::buildURI("giop:ssl:",
+						addr.host, addr.port);
   return giopAddress::str2Address(addrstr);
 }
 
@@ -259,6 +253,14 @@ giopTransportImpl::~giopTransportImpl() {
   if (*pp == this) *pp = this->next;
 }
 
+////////////////////////////////////////////////////////////////////////
+giopTransportImpl*
+giopTransportImpl::str2Transport(const char* endpoint) {
+
+  const char* param;
+  return matchType(endpoint,param,1);
+}
+
 ////////////////////////////////////////////////////////////////////////
 void
 giopConnection::incrRefCount() {
@@ -283,14 +285,10 @@ giopConnection::decrRefCount(CORBA::Boolean forced) {
 }
 
 ////////////////////////////////////////////////////////////////////////
-#if 0
-// Disabled for library binary compatibility.
-
 const char*
 giopConnection::peeridentity() {
   return 0;
 }
-#endif
 
 ////////////////////////////////////////////////////////////////////////
 const omnivector<const char*>*
