@@ -29,8 +29,26 @@
 
 /*
   $Log: giopImpl10.cc,v $
-  Revision 1.1.4.20  2003/07/25 16:07:18  dgrisby
-  Incorrect COMM_FAILURE with GIOP 1.2 CloseConnection.
+  Revision 1.1.6.7  2006/09/20 13:36:31  dgrisby
+  Descriptive logging for connection and GIOP errors.
+
+  Revision 1.1.6.6  2006/06/05 11:28:04  dgrisby
+  Change clientSendRequest interceptor members to a single GIOP_C.
+
+  Revision 1.1.6.5  2005/12/08 14:22:31  dgrisby
+  Better string marshalling performance; other minor optimisations.
+
+  Revision 1.1.6.4  2005/04/11 12:09:42  dgrisby
+  Another merge.
+
+  Revision 1.1.6.3  2005/01/06 23:10:15  dgrisby
+  Big merge from omni4_0_develop.
+
+  Revision 1.1.6.2  2003/07/10 21:55:56  dgrisby
+  Use re-entrant GIOP 1.0 size calc.
+
+  Revision 1.1.6.1  2003/03/23 21:02:16  dgrisby
+  Start of omniORB 4.1.x development branch.
 
   Revision 1.1.4.19  2003/01/22 11:40:12  dgrisby
   Correct serverSendException interceptor use.
@@ -118,9 +136,10 @@
 // the total size of the message before the actual marshalling.
 // The implementation can actually avoid this calculation if full message
 // can be fully buffered.
-// We however have to force pre-calculation because at the moment, the Any
-// marshalling implementation is not re-entrant. 
-#define PRE_CALCULATE_MESSAGE_SIZE
+// The version without pre-calculation can only work if all
+// marshalling code is re-entrant.
+
+//#define PRE_CALCULATE_MESSAGE_SIZE
 
 
 OMNI_NAMESPACE_BEGIN(omni)
@@ -165,13 +184,15 @@ public:
   static CORBA::Boolean inputReplyBegin(giopStream*, 
 					void (*unmarshalHeader)(giopStream*));
 
-  static void inputTerminalProtocolError(giopStream* g);
+  static void inputTerminalProtocolError(giopStream* g,
+					 const char* file, int line,
+					 const char* message);
   // Helper function.  Call this function to indicate that a protocol
   // voilation was detected.  This function *always* raise a
   // giopStream::CommFailure exception.  Therefore the caller should not
   // expect this function to return.
 
-  static void inputRaiseCommFailure(giopStream* g);
+  static void inputRaiseCommFailure(giopStream* g, const char* message);
 
   static void outputNewMessage(giopStream*);
 
@@ -220,7 +241,8 @@ giopImpl10::inputMessageBegin(giopStream* g,
   if (hdr[4] != 1 || hdr[5] != 0) {
     // We accept a CloseConnection message with any GIOP version.
     if ((GIOP::MsgType)hdr[7] != GIOP::CloseConnection) {
-      inputTerminalProtocolError(g);
+      inputTerminalProtocolError(g, __FILE__, __LINE__,
+				 "Invalid GIOP message version");
       // never reaches here.
     }
   }
@@ -283,17 +305,20 @@ giopImpl10::inputReplyBegin(giopStream* g,
     {
       CORBA::ULong minor;
       CORBA::Boolean retry;
+      g->pd_strand->orderly_closed = 1;
       g->notifyCommFailure(0,minor,retry);
       g->pd_strand->state(giopStrand::DYING);
-      g->pd_strand->orderly_closed = 1;
       giopStream::CommFailure::_raise(minor,
 				      CORBA::COMPLETED_NO,
-				      retry,__FILE__,__LINE__);
+				      retry,__FILE__,__LINE__,
+				      "Orderly connection shutdown",
+				      g->pd_strand);
       // never reach here.
       break;
     }
   default:
-    inputTerminalProtocolError(g);
+    inputTerminalProtocolError(g, __FILE__, __LINE__,
+			       "Invalid reply message type");
     // never reaches here.
   }
 
@@ -304,13 +329,15 @@ giopImpl10::inputReplyBegin(giopStream* g,
     if (mtype == GIOP::LocateReply && 
 	unmarshalHeader != unmarshalLocateReply) {
 
-      inputTerminalProtocolError(g);
+      inputTerminalProtocolError(g, __FILE__, __LINE__,
+				 "Unexpected LocateReply");
       // never reach here
     }
     else if (mtype == GIOP::Reply &&
 	     unmarshalHeader != unmarshalReplyHeader) {
 
-      inputTerminalProtocolError(g);
+      inputTerminalProtocolError(g, __FILE__, __LINE__,
+				 "Unexpected Reply");
       // never reach here
     }
 
@@ -337,7 +364,8 @@ giopImpl10::inputReplyBegin(giopStream* g,
 
 	if (target->inputMatchedId()) {
 	  // a reply has already been received!
-	  inputTerminalProtocolError(g);
+	  inputTerminalProtocolError(g, __FILE__, __LINE__,
+				     "Duplicate Reply");
 	}
 
 	target->pd_input = source->pd_input;
@@ -399,7 +427,8 @@ giopImpl10::inputMessageEnd(giopStream* g,CORBA::Boolean disgard) {
 	disgard = 1;
       }
       else {
-	inputTerminalProtocolError(g);
+	inputTerminalProtocolError(g, __FILE__, __LINE__,
+				   "Garbage left at end of input message");
 	// never reach here.
       }
     }
@@ -428,7 +457,9 @@ giopImpl10::unmarshalReplyHeader(giopStream* g) {
   if ((GIOP::MsgType)hdr[7] != GIOP::Reply) {
     // Unexpected reply. The other end is terribly confused. Drop the
     // connection and died.
-    inputTerminalProtocolError(g);
+    inputTerminalProtocolError(g, __FILE__, __LINE__,
+			       "Incorrect message type when expecting a "
+			       "Reply");
     // Never reach here.
   }
 
@@ -469,7 +500,8 @@ giopImpl10::unmarshalReplyHeader(giopStream* g) {
   default:
     // Should never receive anything other that the above
     // Same treatment as wrong header
-    inputTerminalProtocolError(g);
+    inputTerminalProtocolError(g, __FILE__, __LINE__,
+			       "Invalid status in Reply");
     // Never reach here.
     break;
   }
@@ -491,7 +523,9 @@ giopImpl10::unmarshalLocateReply(giopStream* g) {
   if ((GIOP::MsgType)hdr[7] != GIOP::LocateReply) {
     // Unexpected reply. The other end is terribly confused. Drop the
     // connection and died.
-    inputTerminalProtocolError(g);
+    inputTerminalProtocolError(g, __FILE__, __LINE__,
+			       "Incorrect message type when expecting a "
+			       "LocateReply");
     // Never reach here.
   }
 
@@ -513,7 +547,8 @@ giopImpl10::unmarshalLocateReply(giopStream* g) {
   default:
     // Should never receive anything other that the above
     // Same treatment as wrong header
-    inputTerminalProtocolError(g);
+    inputTerminalProtocolError(g, __FILE__, __LINE__,
+			       "Invalid status in LocateReply");
     // Never reach here.
     break;
   }
@@ -532,7 +567,7 @@ giopImpl10::unmarshalWildCardRequestHeader(giopStream* g) {
   ((GIOP_S*)g)->requestType((GIOP::MsgType)hdr[7]);
   switch (((GIOP_S*)g)->requestType()) {
   case GIOP::CloseConnection:
-    inputRaiseCommFailure(g);
+    inputRaiseCommFailure(g, "Orderly connection shutdown");
     break;
   case GIOP::Request:
   case GIOP::LocateRequest:
@@ -542,7 +577,8 @@ giopImpl10::unmarshalWildCardRequestHeader(giopStream* g) {
     }
     // falls through if the message has exceeded the size limit.
   default:
-    inputTerminalProtocolError(g);
+    inputTerminalProtocolError(g, __FILE__, __LINE__,
+			       "Unknown GIOP message type");
     // Never reach here.
     break;
   }
@@ -869,16 +905,26 @@ giopImpl10::currentInputPtr(const giopStream* g) {
 
 ////////////////////////////////////////////////////////////////////////
 void
-giopImpl10::inputTerminalProtocolError(giopStream* g) {
+giopImpl10::inputTerminalProtocolError(giopStream* g,
+				       const char* file, int line,
+				       const char* message) {
+
+  if (omniORB::trace(1)) {
+    omniORB::logger l;
+    l << "From endpoint: " << g->pd_strand->connection->peeraddress()
+      << ". Detected GIOP 1.0 protocol error in input message. "
+      << omniExHelper::strip(file) << ":" << line
+      << ". Connection is closed.\n";
+  }
 
   sendMsgErrorMessage(g);
 
-  inputRaiseCommFailure(g);
+  inputRaiseCommFailure(g, message);
 }
 
 ////////////////////////////////////////////////////////////////////////
 void
-giopImpl10::inputRaiseCommFailure(giopStream* g) {
+giopImpl10::inputRaiseCommFailure(giopStream* g, const char* message) {
 
   CORBA::ULong minor;
   CORBA::Boolean retry;
@@ -886,7 +932,7 @@ giopImpl10::inputRaiseCommFailure(giopStream* g) {
   g->pd_strand->state(giopStrand::DYING);
   giopStream::CommFailure::_raise(minor,
 				  (CORBA::CompletionStatus)g->completion(),
-				  0,__FILE__,__LINE__);
+				  0,__FILE__,__LINE__,message,g->pd_strand);
 }
 
 ////////////////////////////////////////////////////////////////////////
@@ -1023,11 +1069,7 @@ giopImpl10::marshalRequestHeader(giopStream* g) {
   CORBA::Boolean response_expected = !calldesc.is_oneway();
   
 
-  omniInterceptors::clientSendRequest_T::info_T info(*g,
-				                     *(giop_c.ior()),
-						     calldesc.op(),
-						     response_expected,
-						     !response_expected);
+  omniInterceptors::clientSendRequest_T::info_T info(giop_c);
   omniInterceptorP::visit(info);
 
   {
@@ -1044,6 +1086,7 @@ giopImpl10::marshalRequestHeader(giopStream* g) {
     *((CORBA::ULong*)(hdr+8)) = cs.total();
 
 #if defined(PRE_CALCULATE_MESSAGE_SIZE)
+    omniORB::logs(30, "Pre-calculating GIOP 1.0 message size.");
     giop_c.calldescriptor()->marshalArguments(cs);
     CORBA::ULong msgsz = cs.total() - 12;
     *((CORBA::ULong*)(hdr + 8)) = msgsz;
@@ -1062,11 +1105,11 @@ giopImpl10::marshalRequestHeader(giopStream* g) {
 
   // object key
   giop_c.keysize() >>= s;
-  s.put_octet_array(giop_c.key(),giop_c.keysize());
+  s.put_small_octet_array(giop_c.key(),giop_c.keysize());
 
   // operation
   operator>>= ((CORBA::ULong)calldesc.op_len(),s);
-  s.put_octet_array((CORBA::Octet*) calldesc.op(), calldesc.op_len());
+  s.put_small_octet_array((CORBA::Octet*) calldesc.op(), calldesc.op_len());
 
   // principal
   omni::myPrincipalID >>= s;
@@ -1104,7 +1147,7 @@ giopImpl10::sendLocateRequest(giopStream* g) {
   
   // object key
   giop_c.keysize() >>= s;
-  s.put_octet_array(giop_c.key(),giop_c.keysize());
+  s.put_small_octet_array(giop_c.key(),giop_c.keysize());
 
   outputMessageEnd(g);
 }
@@ -1133,6 +1176,7 @@ giopImpl10::marshalReplyHeader(giopStream* g) {
     *((CORBA::ULong*)(hdr+8)) = cs.total();
 
 #if defined(PRE_CALCULATE_MESSAGE_SIZE)
+    omniORB::logs(30, "Pre-calculating GIOP 1.0 message size.");
     giop_s.calldescriptor()->marshalReturnedValues(cs);
     CORBA::ULong msgsz = cs.total() - 12;
     *((CORBA::ULong*)(hdr + 8)) = msgsz;
@@ -1175,7 +1219,10 @@ giopImpl10::sendSystemException(giopStream* g,const CORBA::SystemException& ex)
 	giop_s.notifyCommFailure(0,minor,retry);
 	giopStream::CommFailure::_raise(minor,(CORBA::CompletionStatus)
 					giop_s.completion(),
-					retry,__FILE__,__LINE__);
+					retry,__FILE__,__LINE__,
+					"System Exception occurred while "
+					"marshalling reply. Sending a "
+					"MessageError", g->pd_strand);
       }
   }
 
@@ -1227,7 +1274,7 @@ giopImpl10::sendSystemException(giopStream* g,const CORBA::SystemException& ex)
 
   // system exception value
   CORBA::ULong(repoid_size) >>= s;
-  s.put_octet_array((const CORBA::Octet*) repoid, repoid_size);
+  s.put_small_octet_array((const CORBA::Octet*) repoid, repoid_size);
   ex.minor() >>= s;
   CORBA::ULong(ex.completed()) >>= s;
 
@@ -1285,7 +1332,7 @@ giopImpl10::sendUserException(giopStream* g,const CORBA::UserException& ex) {
 
   // user exception value
   CORBA::ULong(repoid_size) >>= s;
-  s.put_octet_array((const CORBA::Octet*) repoid, repoid_size);
+  s.put_small_octet_array((const CORBA::Octet*) repoid, repoid_size);
   ex._NP_marshal(s);
 
   outputMessageEnd(g);
