@@ -29,8 +29,11 @@
 
 /*
   $Log: giopRendezvouser.cc,v $
-  Revision 1.1.4.7  2005/11/04 14:26:02  dgrisby
-  Open connections would prevent shutdown on Windows.
+  Revision 1.1.6.2  2005/11/17 17:03:26  dgrisby
+  Merge from omni4_0_develop.
+
+  Revision 1.1.6.1  2003/03/23 21:02:15  dgrisby
+  Start of omniORB 4.1.x development branch.
 
   Revision 1.1.4.6  2002/09/09 22:11:50  dgrisby
   SSL transport cleanup even if certificates are wrong.
