@@ -26,8 +26,15 @@
 //   
 //   Abstract Syntax Tree objects and support functions
 
-// $Id: idlast.cc,v 1.22.2.6 2006/11/02 14:00:54 dgrisby Exp $
+// $Id: idlast.cc,v 1.22.2.8 2007/12/05 11:15:15 dgrisby Exp $
 // $Log: idlast.cc,v $
+// Revision 1.22.2.8  2007/12/05 11:15:15  dgrisby
+// Segfault on omniidl exit with forward declaration to previously
+// fully-declared valuetype.
+//
+// Revision 1.22.2.7  2007/10/29 11:32:32  dgrisby
+// Error with escaped identifiers in union members.
+//
 // Revision 1.22.2.6  2006/11/02 14:00:54  dgrisby
 // Remove a few warnings.
 //
@@ -156,6 +163,8 @@
 // *** empty log message ***
 //
 
+#include <iostream>
+
 #include <idlast.h>
 #include <idlrepoId.h>
 #include <idlvalidate.h>
@@ -951,7 +960,7 @@ Forward(const char* file, int line, IDL_Boolean mainFile,
 Forward::
 ~Forward()
 {
-  delete thisType_;
+  if (thisType_) delete thisType_;
 }
 
 Interface*
@@ -1455,7 +1464,7 @@ StructForward(const char* file, int line, IDL_Boolean mainFile,
 StructForward::
 ~StructForward()
 {
-  delete thisType_;
+  if (thisType_) delete thisType_;
 }
 
 Struct*
@@ -1687,7 +1696,7 @@ UnionCase(const char* file, int line, IDL_Boolean mainFile,
       }
     }
   }
-  Scope::current()->addInstance(declarator->identifier(), declarator,
+  Scope::current()->addInstance(declarator->eidentifier(), declarator,
 				caseType, declarator->file(),
 				declarator->line());
 }
@@ -1964,7 +1973,7 @@ UnionForward(const char* file, int line, IDL_Boolean mainFile,
 UnionForward::
 ~UnionForward()
 {
-  delete thisType_;
+  if (thisType_) delete thisType_;
 }
 
 Union*
@@ -2388,10 +2397,11 @@ ValueForward(const char* file, int line, IDL_Boolean mainFile,
   : ValueBase(D_VALUEFORWARD, file, line, mainFile, identifier),
     abstract_(abstract),
     definition_(0),
-    firstForward_(0)
+    firstForward_(0),
+    thisType_(0)
 {
-  Scope::Entry*  se  = Scope::current()->find(identifier);
-  IDL_Boolean reg = 1;
+  Scope::Entry* se  = Scope::current()->find(identifier);
+  IDL_Boolean   reg = 1;
 
   if (se && se->kind() == Scope::Entry::E_DECL) {
 
@@ -2486,7 +2496,7 @@ ValueForward(const char* file, int line, IDL_Boolean mainFile,
 ValueForward::
 ~ValueForward()
 {
-  delete thisType_;
+  if (thisType_) delete thisType_;
 }
 
 ValueBase*
